@@ -1,5 +1,5 @@
 def initConfig():
-    url = "http://127.0.0.1:8000/app_finance/getcodeconfig"
+    url = "http://106.53.251.60/app_finance/getcodeconfig"
     import requests,json
     res = requests.get(url, timeout=60)
     ClassCodeConfig.config = json.loads(res.text)
